# indoQuake-latest-info
This package extracts the latest earthquake information from the official website of the Indonesian Meteorology, Climatology, and Geophysics Agency (BMKG)

It utilizes the requests library to fetch the HTML content of the website and the BeautifulSoup library to parse the HTML and extract the desired earthquake data, which is then formatted in JSON format
